.. _installation:

============
Installation
============

**twined** is available on pypi, so installation into your python virtual environment is dead simple:

.. code-block::

    pip install twined

Don't have a virtual environment with pip? You probably should! pyenv is your friend. Google it.


.. _compilation:
Compilation
============

There is presently no need to compile **twined**, as it's written entirely in python.


.. _third_party_library_installation:
Third party library installation
================================

**twined** is for python >= 3.6 so expects that. Other dependencies can be checked in ``setup.py``, and will
automatically installed during the installation above.


.. _third_party_build_requirements:
Third party build requirements
==============================

.. ATTENTION::
    Woohoo! There are no crazy dependencies that you have to compile and build for your particular system.
     (you know the ones... they never *actually* compile, right?). We aim to keep it this way.
